@@ -2,11 +2,10 @@
 
 use Modern::Perl;
 use autodie qw(:all);
-use version ; our $VERSION = qv('1.0.4');
+use version ; our $VERSION = qv('1.0.1');
 
 use Carp;
 use Getopt::Euclid qw( :vars<opt_> );
-use List::MoreUtils qw{firstidx} ;
 
 use Array::Diff ;
 use List::Util qw(first max maxstr min minstr reduce shuffle sum);
@@ -34,9 +33,6 @@ my %ValidParserMakeArgs = ( vb  => "NET::VB"
                           , xls => "XLS"
                           , xml => "XML"
                           ) ;
-my %ValidParserMakeArgs2 = ( vb  => "NET2::VB"
-                           , cs  => "NET2::CS"
-                           ) ;                          
 
 my %Parsers         = () ;
 
@@ -62,34 +58,13 @@ my %Parsers         = () ;
         my %resSetNotEmptyEtc = () ;
 
         (my $insfx  = $testFile)  =~ s/^.*\.//g;
-        croak 'Invalid input file'   unless defined $insfx ;            
         $insfx  = lc $insfx ;
 
         die 'Invalid input file $testFile'  unless exists $ValidParserMakeArgs{$insfx} ;
 
-        $Parsers{${insfx}}     = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${insfx}} } )
+        $Parsers{${insfx}}  = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs{${insfx}} } )
             if not exists $Parsers{${insfx}} ;
-        # if input is in a .net language, add in a .net2 parser to the list
-        if ( firstidx { $_ eq ${insfx} } ['cs','vb']  != -1 ) {
-            $Parsers{"${insfx}2"}  = VSGDR::UnitTest::TestSet::Representation->make( { TYPE => $ValidParserMakeArgs2{${insfx}} } )
-                if not exists $Parsers{"${insfx}2"} ;
-        }
-
-        my $testSet         = undef ;
-        eval {
-            $testSet         = $Parsers{$insfx}->deserialise($testFile);
-            } ;
-        if ( not defined $testSet ) {
-            if ( exists $Parsers{"${insfx}2"}) {
-                eval {
-                    $testSet     = $Parsers{"${insfx}2"}->deserialise($testFile);
-                    }
-            }            
-            else {
-                croak 'Parsing failed.'; 
-            }
-        }
-
+        my $testSet         = $Parsers{$insfx}->deserialise($testFile);
 
         my $ra_tests  = $testSet->tests() ;
         @testNames = map { $_->testName() } @{$ra_tests} ;
@@ -118,8 +93,6 @@ else {
             my @scalarPreTestConditionNames     = map { $_->conditionName() } grep { $_->conditionEnabled() or $includeDisabledConditions } @{$ra_preTestConditions} ;
             my @scalarPostTestConditionNames    = map { $_->conditionName() } grep { $_->conditionEnabled() or $includeDisabledConditions } @{$ra_postTestConditions} ;
 
-warn Dumper @{$ra_testConditions} ;
-
             map { push @{$resSets{$test->testName()}}, $_->conditionResultSet() }
                 @{$ra_testConditions} ;
 
@@ -419,7 +392,7 @@ reportGDRTests.pl - Reports on Test and Test Conditions within a GDR Unit Test f
 
 =head1 VERSION
 
-1.0.4
+1.0.1
 
 
 
